@@ -375,7 +375,7 @@ IPState SteelDriveII::MoveRelFocuser(FocusDirection dir, uint32_t ticks)
     uint32_t limit = std::stoul(m_Summary[LIMIT]);
 
     int direction = (dir == FOCUS_INWARD) ? -1 : 1;
-    int reversed = (FocusReverseS[REVERSED_ENABLED].s == ISS_ON) ? -1 : 1;
+    int reversed = (FocusReverseS[INDI_ENABLED].s == ISS_ON) ? -1 : 1;
     int relative = static_cast<int>(ticks);
     int targetAbsPosition = FocusAbsPosN[0].value + (relative * direction * reversed);
 
