@@ -83,7 +83,7 @@ class CelestronGPS : public INDI::Telescope, public INDI::GuiderInterface, publi
         void guideTimer(CELESTRON_DIRECTION dirn);
 
         void AddGuideTimer(CELESTRON_DIRECTION dirn, int ms);
-
+        
         // Focus Backlash
         virtual bool SetFocuserBacklash(int32_t steps) override;
 
@@ -120,9 +120,9 @@ class CelestronGPS : public INDI::Telescope, public INDI::GuiderInterface, publi
         //ISwitch TrackS[4];
         //ISwitchVectorProperty TrackSP;
 
-        // Celestron Track Mode (AltAz, EQ N, EQ S)
+        // Celestron Track Mode (AltAz, EQ N, EQ S, Ra and Dec)
         ISwitchVectorProperty CelestronTrackModeSP;
-        ISwitch CelestronTrackModeS[3];
+        ISwitch CelestronTrackModeS[4];
 
         //GUIDE Pulse guide switch
 //        ISwitchVectorProperty UsePulseCmdSP;
@@ -168,16 +168,23 @@ class CelestronGPS : public INDI::Telescope, public INDI::GuiderInterface, publi
 
         //CelestronGuide guider;
 
-        // experimental last align property
+        // Last align property
         ISwitch LastAlignS[1];
         ISwitchVectorProperty LastAlignSP;
 
+        // DST setting
+        ISwitch DSTSettingS[1];
+        ISwitchVectorProperty DSTSettingSP;
+
         bool slewToIndex;
 
         size_t numPecBins = 0;
 
         bool savePecData();
 
+        // Slew Offsets
+        double SlewOffsetRa = 0.0;
+
         // focuser
         //        INumber FocusBacklashN[1];
         //        INumberVectorProperty FocusBacklashNP;
