@@ -52,7 +52,9 @@ bool Base::initCommunication(int fd)
             {
                 if (oneMount.model == m_FirmwareInfo.Model)
                 {
-                    if (oneMount.firmware >= m_FirmwareInfo.MainBoardFirmware)
+                    // Make sure current mount firmware is larger
+                    // than the minimum firmware required by this mount model.
+                    if (m_FirmwareInfo.MainBoardFirmware >= oneMount.firmware)
                         return true;
                     else
                         LOGF_ERROR("Main board firmware is %s while minimum required firmware is %s. Please upgrade the mount firmware.",
@@ -710,10 +712,11 @@ bool Base::isCommandSupported(const std::string &command, bool silent)
     if (command == "MSH")
     {
         if (m_FirmwareInfo.Model.find("CEM60") == std::string::npos &&
-                m_FirmwareInfo.Model.find("CEM40") == std::string::npos)
+                m_FirmwareInfo.Model.find("CEM40") == std::string::npos &&
+                m_FirmwareInfo.Model.find("GEM45") == std::string::npos)
         {
             if (!silent)
-                LOG_ERROR("Finding home is only supported on CEM40 and CEM60 mounts.");
+                LOG_ERROR("Finding home is only supported on CEM40, GEM45 and CEM60 mounts.");
             return false;
 
         }
@@ -740,10 +743,11 @@ bool Base::isCommandSupported(const std::string &command, bool silent)
     {
         if (m_FirmwareInfo.Model.find("CEM60") == std::string::npos &&
                 m_FirmwareInfo.Model.find("CEM40") == std::string::npos &&
+                m_FirmwareInfo.Model.find("GEM45") == std::string::npos &&
                 m_FirmwareInfo.Model.find("iEQ") == std::string::npos)
         {
             if (!silent)
-                LOG_ERROR("Parking only supported on CEM40, CEM60, iEQPro 30 and iEQ Pro 45.");
+                LOG_ERROR("Parking only supported on CEM40, GEM45, CEM60, iEQPro 30 and iEQ Pro 45.");
             return false;
         }
     }
