@@ -20,6 +20,7 @@
 
 #include "indiguiderinterface.h"
 #include "inditelescope.h"
+#include "scopesim_helper.h"
 
 /**
  * @brief The ScopeSim class provides a simple mount simulator of an equatorial mount.
@@ -54,6 +55,7 @@ class ScopeSim : public INDI::Telescope, public INDI::GuiderInterface
     virtual bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
 
   protected:
+    // Slew Rate
     virtual bool MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command) override;
     virtual bool MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command) override;
     virtual bool Abort() override;
@@ -75,6 +77,9 @@ class ScopeSim : public INDI::Telescope, public INDI::GuiderInterface
     // Parking
     virtual bool SetCurrentPark() override;
     virtual bool SetDefaultPark() override;
+    virtual bool updateLocation(double latitude, double longitude, double elevation) override;
+
+    virtual bool saveConfigItems(FILE *fp) override;
 
 private:
     double currentRA { 0 };
@@ -88,12 +93,40 @@ private:
     bool forceMeridianFlip { false };
     unsigned int DBG_SCOPE { 0 };
 
-    double guiderEWTarget[2];
-    double guiderNSTarget[2];
+    int mcRate = 0;
+
+//    double guiderEWTarget[2];
+//    double guiderNSTarget[2];
+
+    bool guidingNS = false;
+    bool guidingEW = false;
 
     INumber GuideRateN[2];
     INumberVectorProperty GuideRateNP;
 
+    Axis axisPrimary { "HaAxis" };         // hour angle mount axis
+    Axis axisSecondary { "DecAxis" };       // declination mount axis
+
+    Alignment alignment;
+    void updateMountAndPierSide();
+
+#ifdef USE_SIM_TAB
+    // Simulator Tab properties
+    // Scope type and alignment
+    ISwitch mountTypeS[3];
+    ISwitchVectorProperty mountTypeSP;
+    ISwitch simPierSideS[2];
+    ISwitchVectorProperty simPierSideSP;
+
+    INumber mountModelN[6];
+    INumberVectorProperty mountModelNP;
+    INumber mountAxisN[2];
+    INumberVectorProperty mountAxisNP;
+
+    INumber flipHourAngleN[1];
+    INumberVectorProperty flipHourAngleNP;
+#endif
+
 #ifdef USE_EQUATORIAL_PE
     INumberVectorProperty EqPENV;
     INumber EqPEN[2];
@@ -105,3 +138,4 @@ private:
     ISwitchVectorProperty PEErrWESP;
 #endif
 };
+
